pub trait CarveSkipChecker {
// Required method
fn should_skip(&mut self, xd: f64, yd: f64, zd: f64, world_y: i32) -> bool;
}Expand description
Predicate called inside the carver’s Y scan to decide whether a block is
outside the carved shape for a given ellipsoid (cave floor cutoff, canyon
width-by-height, etc). Matches vanilla’s WorldCarver.CarveSkipChecker.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".